# Quple

A framework for quantum machine learning using the google cirq library

## Feature Map Tutorial

* Tutorial I: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/Deployment/Feature_Map/Feature_Map_Walkthrough.ipynb)

## Trial Wavefunction/ Parameterised Circuit Tutorial

* Tutorial I: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/Deployment/Trial_Wavefunction/Trial_Wavefunction_Walkthrough.ipynb)


## Parameter Resolver and Resolved Circuit Tutorial
* Tutorial I: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/Deployment/ParamResolver/EncodingCircuitWithParamResolver.ipynb)

## Circuit Descriptors
* Tutorial : [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/Deployment/Circuit_Descriptors/Properties_of_PQC.ipynb)
